==> resource-updater-cli-0.0.1-20181004.155128-1-sources.jar: org/gcube/resourcemanagement/updater/AccessPointEraser.java <==
/**
 * 
 */
package org.gcube.resourcemanagement.updater;

import java.io.IOException;
import java.util.Properties;

import org.gcube.common.resources.gcore.ServiceEndpoint;
import org.gcube.common.resources.gcore.ServiceEndpoint.AccessPoint;

/**
 * @author Roberto Cirillo (ISTI-CNR) 2018
 *
 */
public class AccessPointEraser {
	
	/**
	 * @param args
	 * @throws IOException 
	 */
	public static void main(String[] args) throws IOException {
		for (int i=0; i<args.length;i++) 
			System.out.println("param N." +i + ": " + args[i]);
		
		if((args.length != 5)){
			System.out.println("Usage:");
			System.out.println("\tjava  AccessPointEraser scope  Category Name AccessEndpointName file.properties\n\n");
			System.out.println("Example:");
			System.out.println("\tjava  AccessPointEraser  /gcube DataAnalysis Dataminer dataminer.garr.d4science.org /test/environment.properties \n\n");
			return;
		}
		
		String scope=args[0];
		String category=args[1];
		String name=args[2];
		String accessEndpointName=args[3];
		String filePath=args[4]; 
		Properties props=Utils.loadProperties(filePath);
		ServiceEndpoint resource = Utils.getResource(scope, category, name);
		AccessPoint accesspoint = Utils.getAccessPoint(resource, accessEndpointName);
		if (accesspoint != null){
			delete(props, accesspoint);
			Utils.update(resource);
		}else{
			System.out.println("access point not found");
		}
	}

	private static void delete(Properties props, AccessPoint point) {
		   for(String name : props.stringPropertyNames()) {
	        	  String value = props.getProperty(name);
	        	  System.out.println("Removing "+name+ " "+value);
	        	  point.properties().remove(new ServiceEndpoint.Property().nameAndValue(name, value));
		   }
	}
	



}

==> resource-updater-cli-1.2.0-20211001.110307-12-sources.jar: org/gcube/resourcemanagement/updater/AccessPointEraser.java <==
/**
 * 
 */
package org.gcube.resourcemanagement.updater;

import java.io.IOException;
import java.util.List;
import java.util.Properties;

import org.gcube.common.resources.gcore.ServiceEndpoint;
import org.gcube.common.resources.gcore.ServiceEndpoint.AccessPoint;

/**
 * @author Roberto Cirillo (ISTI-CNR) 2018
 *
 */
public class AccessPointEraser {
	
	/**
	 * @param args
	 * @throws IOException 
	 */
	public static void main(String[] args) throws IOException {
		for (int i=0; i<args.length;i++) 
			System.out.println("param N." +i + ": " + args[i]);
		
		if((args.length != 5)){
			System.out.println("Usage:");
			System.out.println("\tjava  AccessPointEraser scope  Category Name AccessEndpointName file.properties\n\n");
			System.out.println("Example:");
			System.out.println("\tjava  AccessPointEraser  /gcube DataAnalysis Dataminer dataminer.garr.d4science.org /test/environment.properties \n\n");
			return;
		}
		
		String scope=args[0];
		String category=args[1];
		String name=args[2];
		String accessEndpointName=args[3];
		String filePath=args[4]; 
		Properties props=Utils.loadProperties(filePath);
		List <ServiceEndpoint> resources = Utils.getResources(scope, category, name);
		if(resources!=null){
			System.out.println("resources found: "+resources.size());
			for(ServiceEndpoint resource: resources){
				AccessPoint accesspoint = Utils.getAccessPoint(resource, accessEndpointName);
				if (accesspoint != null){
					delete(props, accesspoint);
					Utils.update(resource);
				}
			}
		}else{
			System.out.println("No resource found on scope "+scope+" with category: "+category+" and name: "+name);
		}
	}

	private static void delete(Properties props, AccessPoint point) {
		   for(String name : props.stringPropertyNames()) {
	        	  String value = props.getProperty(name);
	        	  System.out.println("Removing "+name+ " "+value);
	        	  point.properties().remove(new ServiceEndpoint.Property().nameAndValue(name, value));
		   }
	}
	



}
